#! /usr/local/bin/perl5
#############################################################################
#  
#   File:          Action.pl
#
#   Author:        Jungmin Kim
#
#   Created:       03/01/95
#   Modified:      03/20/95
#   Version: 
#
#   Input:         subject, path, filename, username
#   Output:        HTML text 
#          
#
#   Description:   This program is the main function of WeBBoard which
#                  is a networked conferencing and bulletin board 
#                  system based on the World Wide Web.
#               
#   Usage:         All arguments are passed through 'PATH_INFO'
#                  and 'POST' method.
#                  
#     example: http://.../Action.pl               Starting the program
#              http://.../Action.pl/read:path:file:user
#                                    Read a conference in the directory,
#                                    'path'. Current message is 'file'
#                                    and current user information is 'user'
#              Format of 'user' is "username:email_address"
#              Space characters should be replaced with '+' characters.
#
#############################################################################

require "Global.pl";		# sets global variables
require "ParseArg.pl";		# parses the passed arguments
require "SelectBoard.pl";	# generates index page for conferences
require "ReadBoard.pl";		# reads messages
require "PostMessage.pl";	# edits a new message
require "PreviewMessage.pl";	# previews the edited message
require "GetDate.pl";		# gets the current date
require "PostIt.pl";		# generates new message 
require "CheckPasswd.pl";	# checks out the entered password
require "Entry.pl";		# entry form for password
require "Retry.pl";		# retry entering password


# ***********************************************************************
#
#  MAIN FUNCTION
#
# ***********************************************************************

&Global();
%in = ();
&ParseArg(*in);			# parse arguments passed by http server
&GetPath(*in);			# parse arguments passed by 'PATH_INFO'
%conference = ();
&ReadConf(*conference);		# read conference names

if($in{'subject'} eq "read") {

    #### read a conference in directory 'path', current file is 'file'
    &ReadBoard($in{'path'}, $in{'file'}, $in{'user'});
}
elsif($in{'subject'} eq "select") {

    #### select a conference
    &SelectBoard($in{'user'});
}
elsif($in{'subject'} eq "post") {

    #### edit a message
    &PostMessage($in{'path'}, $in{'file'}, 
		 $in{'title'}, $in{'message'},
		 $in{'hdate'}, $in{'hname'},
		 $in{'htitle'}, $in{'hmessage'}, 
		 $in{'method'}, $in{'user'});
}
elsif($in{'subject'} eq "preview") {

    #### preview the edited message
    &PreviewMessage($in{'path'}, $in{'file'},
		    $in{'title'}, $in{'message'},
		    $in{'hdate'}, $in{'hname'},
		    $in{'htitle'}, $in{'hmessage'}, 
		    $in{'method'}, $in{'user'});
}
elsif($in{'subject'} eq "postit") {

    #### current message should be edited
    if($in{'edit'} eq  "yes") {
	&PostMessage($in{'path'}, $in{'file'},
		     $in{'title'}, $in{'message'},
		     $in{'hdate'}, $in{'hname'},
		     $in{'htitle'}, $in{'hmessage'}, 
		     $in{'method'}, $in{'user'});
    }

    #### post the message, and then read the conference
    else {
	$in{'file'} = &MakeNewFile($in{'path'}, $in{'file'}, $in{'method'},
		$in{'user'}, $in{'title'}, $in{'message'}); 
	&ReadBoard($in{'path'}, $in{'file'}, $in{'user'});
    }
}
elsif($in{'subject'} eq "check") {

    #### check the entered password
    $user = &CheckPasswd($checkfile, $in{'username'}, $in{'passwd'});

    #### if password is incorrect, retry 
    if($user eq "0") {
	&Retry();
    }

    #### if password is correct, go to the page for index of conference
    else {
	&SelectBoard($user);
    }
}
elsif($in{'subject'} eq "entry") {

    #### get a user name
    &Entry();
}


##########################################################################
#
#  GetPath
#
#  INPUT:    void
#  OUTPUT:   void
#
#  FUNCTION: Parses extended path information.
#            format of 'PATH_INFO' is /subject:path:filename:user.
#            When 'PATH_INFOR is null, action is entering a password.
#            If extended path is '/check', the next action is checking
#            the password entered.
#            The other cases, 'subject' is the next action.
#
##########################################################################

sub GetPath{
    local(*in) = @_;

    if ($ENV{'PATH_INFO'} =~ /^$/) {
	$in{'subject'} = "entry";
	return;
    }
    elsif ($ENV{'PATH_INFO'} =~ /\/check/) {
	$in{'subject'} = "check";
	return;
    }

    $ENV{'PATH_INFO'} =~ /\/([^:]*):([^:]*):([^:]*):(.*)/;
    $in{'subject'} = $1 if $in{'subject'} eq "";
    $in{'path'} = $2;
    $in{'file'} = $3;
    $in{'user'} = $4;
}
1;

# ********************************************************** added

##########################################################################
#
#  ReadConf
#
#  INPUT:    associate array
#  OUTPUT:   void
#
#  FUNCTION: Read conference file
#
##########################################################################

sub ReadConf{
    local(*conference) = @_;
    local($confname, $dirname);

    open(INFILE, "<$conffile") ||
	print "Content-type\: text/html\n\n\n Cannot open $conffile\: $!";
    while(<INFILE>) {
	chop;
	($confname, $dirname) = split(/\005/, $_);
	$conference{$dirname} = $confname;
    }
    close(INFILE);   
}
1;

# ******************************************************************
