#! /usr/local/bin/perl5
#############################################################################
#  
#   File:          ReadBoard.pl
#
#   Author:        Jungmin Kim
#
#   Created:       03/05/95
#   Modified:      
#   Version: 
#
#   Input:         path name, file name, user information
#   Output:        HTML text
#          
#
#   Description:   Print out headers of messages in the path and specified 
#                  files. function PrintHeader is for printing headers, and
#                  function PrintFile is for printing messages.
#                  function dotoder sorts file names in hierachical numbering
#                  order.
#               
#   Usage:         "http://..../Action.pl/read:path:filename:user"
#                  'user' should be "username:email_address".
#
#############################################################################

require "PrintHeader.pl";
require "PrintHeader2.pl";
require "PrintFile.pl";

sub ReadBoard{

    local($path, $file, $user) = @_;
    local($prev, @entry, %array, $d, $t, $n, $pathname, $message);
    local($oldm, $oldn, $oldd, $oldt);

    print "Content-type\: text/html\n\n";
    print "\n";
    print "<TITLE> READ MESSAGES </TITLE>\n";
    print "<H1> Read Messages </H1>\n";
    print "<HR>\n";

    $pathname = $conference{$path};
    print "<B>CONFERENCE\: </B>$pathname \n";
    print "<P>\n";
	
    # explain icon for adding new message
    if($user ne "guest") {
	print "<IMG SRC=\"$gif/pencil.gif\" ALIGN=\"left\" ALT=\"\">";
	print "<i>Click on this icon, which appears next to each message, <BR>\n";
        print "to respond to that message or post a new message.</i> \n";
        print "<P>\n";
    }

    print "<A HREF=\"$action/select\:$path\:\:$user\">\n";
    print "<B>RETURN to the index of conferences</B></A>\n";
    print "<P>\n";
    print "<A HREF=\"$action/read\:$path\:\:$user#subject\">\n";
    print "<B>JUMP to the list of messages ordered by subject</B></A>\n";
    print "<P>\n";
    print "<HR>\n";

    #### array for file names to be printed
    %array = ();


    #### print out all headers of messages in directory $path in reverse
    #### time order
    print "<B>List of messages ordered by time of posting</B>\n";
    &PrintHeader($path, $file, $user, *array);
    print "<HR>\n";
    print "<HR>\n";

    #### print out all headers of messages in directory $path in numerical
    #### order
    print "<A NAME = subject>\n";
    print "<B>List of messages ordered by subject of posting</B></A>\n";
    &PrintHeader2($path, $file, $user);
    print "<HR>\n";
    print "<HR>\n";

    #### print messages coresponding to returned file names
    foreach $next (sort dotorder keys %array) {
	$_ = $next;

	# indentation for hierachical view
	print "<DL>\n";
	while ( /^[0-9]*\.(.*)/ ) {  # number of dots is number of tabs
	    $_ = $1;
	    print "<DL>\n";
	}

	print "<A NAME=\"$next\">\n";

        # separator for each field is eot(\005) *************** modified
	#### split the passed string associated to the file name
	($d, $n, $t) = split(/\005/, $array{$next});

	$message = &PrintFile($path, "$next.html");

	$oldm = $message;
        $oldt = $t;
        $oldn = $n;
	$oldd = $d;

	$d = &Replace($d);
	$n = &Replace($n);
	$t = &Replace($t);
	$message = &Replace($message);

	print "<DT>\n";
	
	# icon for adding new message
	#### if the user name is 'guest', do not print the submit icon
        if($user ne "guest") {
	    print "<A HREF=\"$action/post\:$path\:$next\:$user";
	    print "\?hdate=$d\&hname=$n\&htitle=$t\&hmessage=$message\">\n";
	    print "<IMG SRC=\"$gif/pencil.gif\" ALIGN=\"bottom\" ALT=\"\">";
	    print "</A>\n";
	}

	print "<b>$next\:</b> ";

	# Changed back so it doesn't print title on new line
	print "From <I><B>$oldn</B></I>\n";
	print "on $oldd\n";
	print "regarding <B>$oldt</B><BR>\n";
        # **************************************************************
	
	print "<P>\n";

	#### print out message
	print $oldm;
	print "<P><HR>\n";

	#### close indentation
	$_ = $next;
	while ( /^[0-9]*\.(.*)/ ) { # number of dots is number of tabs
	    $_ = $1;
	    print "</DL>\n";
	}
	print "</DL>\n";
    }
    print "<ADDRESS>\n";
    print "Send comments and suggestions about WeBBoard to \n";
    print "<A HREF=\"$webteam\">the WeBBoard development team</A>.\n";
    print "</ADDRESS>\n";
}
1;

#############################################################################
#
#   dotorder
#
#   INPUT:     $a, $b (system arguments passed by function sort(). )
#   OUTPUT:    greater than, less than, or equal
#
#   FUNCTION:  Compare $a and $b with hierachical numbering order, 
#              and returns -1, 0, 1.
#
#############################################################################

sub dotorder {
    $c = $a;
    $d = $b;

    for(;;){
	$c =~ s/^(\d*)(\.)*//;            # remove prefix of $a
	$e = $1;		          # copy the prefix of $a
	$d =~ s/^(\d*)(\.)*//;            # remove prefix of $b
	$f = $1;		          # copy the prefix of $b
	last if $e != $f;	          # compare prefixes of each numbers
    }
    return $e <=> $f;
}
1;

#############################################################################
#
#   Replace
#
#   INPUT:     string
#   OUTPUT:    exactly same format as 'QUERY_STRING' in 'GET' method
#
#   FUNCTION:  convert special characters to hex numbers
#
#############################################################################

sub Replace {
    local($st) = @_;
    $_ = $st;
    s/\%/%25/g;
    s/\n/%0A/g;
    s/\r/%0D/g;
    s/\t/%09/g;
    s/\!/%21/g;
    s/\"/%22/g;
    s/\#/%23/g;
    s/\$/%24/g;
    s/\&/%26/g;
    s/\'/%27/g;
    s/\(/%28/g;
    s/\)/%29/g;
    s/\+/%2B/g;
    s/\,/%2C/g;
    s/\//%2F/g;
    s/\:/%3A/g;
    s/\;/%3B/g;
    s/\</%3C/g;
    s/\=/%3D/g;
    s/\>/%3E/g;
    s/\?/%3F/g;
    s/\[/%5B/g;
    s/\\/%5C/g;
    s/\]/%5D/g;
    s/\^/%5E/g;
    s/\`/%60/g;
    s/\{/%7B/g;
    s/\|/%7C/g;
    s/\}/%7D/g;
    s/\~/%7E/g;
    s/ /\+/g;
    $_;
}
1;
